#!/usr/bin/perl -w

#--------------------------------------------------------------------
# Fichero:  fondear.pl
# Objetivo: Cambiar la imagen de fondo a partir de las imgenes de
#           un directorio
# Autor:    Pedro Reina
# Fecha:    J.4.7.2002
#--------------------------------------------------------------------

#---------------------------------
# Declaracin de mdulos
#---------------------------------

use strict;              # Comprobaciones estrictas
use Gtk;                 # Interfaz grfico GTK

#---------------------------------
# Declaracin de variables Perl
#---------------------------------

# Orden para poner la imagen en el fondo
my $Orden      = "/usr/bin/xloadimage -onroot";

# Directorio de donde se toman las imgenes
my $Directorio = "/home/pedro/dat/imagen/";

my $Numero = 0;          # El nmero de imagen en pantalla
my $Total  = 0;          # Total de imgenes en el directorio
my @ListaArchivo;        # Array con los nombres de archivos


#---------------------------------
# Declaracin de variables GTK
#---------------------------------

my $Ventana;             # Ventana de la aplicacin
my $Etiqueta;            # Un titulito
my $BotonPrimera;        # El botn para ir a la primera imagen
my $BotonUltima;         # El botn para ir a la ltima imagen
my $BotonAnterior;       # El botn para ir a la imagen anterior
my $BotonSiguiente;      # El botn para ir a la imagen siguiente
my $BotonCerrar;         # El botn para cerrar la aplicacin
my $Tabla;               # Un contenedor para los controles

#---------------------------------
# Programa principal
#---------------------------------

# Preparamos el listado de imgenes
Prepara();

# Arrancamos el motor GTK;
init Gtk;

# Creamos la ventana principal
$Ventana = new Gtk::Window ("toplevel");

# Le ponemos un ttulo
$Ventana->set_title ("Fondear");

# Le ponemos un poquito de borde
$Ventana->border_width (10);

# Creamos la tabla para poner los controles
$Tabla = new Gtk::Table (4, 2, 1);

# Separamos un poquito las celdas
$Tabla->set_row_spacings (4);
$Tabla->set_col_spacings (4);

# Definimos una etiqueta
$Etiqueta = new Gtk::Label ("Fondear (Pedro Reina)");

# Definimos los botones
$BotonPrimera = new Gtk::Button ("Primera");
$BotonUltima = new Gtk::Button ("Ultima");
$BotonAnterior = new Gtk::Button ("Anterior");
$BotonSiguiente = new Gtk::Button ("Siguiente");
$BotonCerrar = new Gtk::Button ("Cerrar");

# Aadimos los controles a la tabla
$Tabla->attach_defaults ($Etiqueta, 0, 2, 0, 1);
$Tabla->attach_defaults ($BotonPrimera, 0, 1, 1, 2);
$Tabla->attach_defaults ($BotonUltima, 1, 2, 1, 2);
$Tabla->attach_defaults ($BotonAnterior, 0, 1, 2, 3);
$Tabla->attach_defaults ($BotonSiguiente, 1, 2, 2, 3);
$Tabla->attach_defaults ($BotonCerrar, 0, 2, 3, 4);

# Mostramos los controles
$BotonPrimera->show();
$BotonUltima->show();
$BotonAnterior->show();
$BotonSiguiente->show();
$BotonCerrar->show();
$Etiqueta->show();

# Registramos las llamadas para cambiar el fondo
$BotonPrimera->signal_connect ("clicked", \&Cambia, "Primera");
$BotonUltima->signal_connect ("clicked", \&Cambia, "Ultima");
$BotonAnterior->signal_connect ("clicked", \&Cambia, "Anterior");
$BotonSiguiente->signal_connect ("clicked", \&Cambia, "Siguiente");

# Registramos las llamadas para cerrar la aplicacin
$Ventana->signal_connect ("delete_event", \&CerrarAplicacion);
$BotonCerrar->signal_connect ("clicked", \&CerrarAplicacion);

# Aadimos la tabla a la ventana
$Ventana->add ($Tabla);

# Mostramos la caja
$Tabla->show();

# Mostramos la ventana
$Ventana->show();

# El resto es cosa de GTK
main Gtk;

# As que hasta aqu no se debera llegar nunca
exit (0);

#---------------------------------
# Funciones
#---------------------------------

sub CerrarAplicacion
  {
  Gtk->exit (0);
  return (0);
  }

sub Prepara
  {
  my $Listado = "";   # Listado de archivos

  # Averiguamos las imgenes que hay en el directorio
  $Listado = qx (ls --color=never -1 $Directorio*.jpg);

  # Formamos un array con el listado
  @ListaArchivo = split (/\n/, $Listado);

  # Calculamos cantas imgenes hay disponibles
  $Total = push(@ListaArchivo);

  # Nos colocamos en la primera imagen
  $Numero = 0;
  }

sub Cambia
  {
  my $Archivo = "";

  # Recibimos los parmetros
  my ($Boton, $Texto) = @_;

  # Vamos a la imagen que nos pidan

  if ( $Texto eq "Primera" )
    { $Numero = 0; }

  if ( $Texto eq "Ultima" )
    { $Numero = $Total-1; }

  if ( $Texto eq "Anterior" )
    {
    $Numero--;
    if ( $Numero < 0 )
      { $Numero = 0; }
    }

  if ( $Texto eq "Siguiente" )
    {
    $Numero++;
    if ( $Numero >= $Total )
      { $Numero = $Total-1; }
    }

  # Tomamos la imagen
  $Archivo = $ListaArchivo[$Numero];

  # Mostramos la imagen en pantalla
  system $Orden . " " . $Archivo;
  }
